@@ -1,22 +1,7 @@
 /*
-    This file is part of Konsole, KDE's terminal emulator.
+    SPDX-FileCopyrightText: 2012 Jekyll Wu <adaptee@gmail.com>
 
-    Copyright 2012 by Jekyll Wu <adaptee@gmail.com>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ENUMERATION_H
@@ -103,6 +88,21 @@ public:
         PasteFromClipboard = 1
     };
 
+    /**
+     * This enum describes the text editor cmd used to open local text file URLs
+     * in Konsole, where line and column data are appended to the file URL, e.g.:
+     * /path/to/file:123:123
+     */
+    enum TextEditorCmd {
+        Kate = 0,
+        KWrite,
+        KDevelop,
+        QtCreator,
+        Gedit,
+        gVim,
+        CustomTextEditor,
+    };
+
     /**
      * This enum describes the different types of sounds and visual effects which
      * can be used to alert the user when a 'bell' occurs in the terminal
