@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2007 by Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2007 Robert Knight <robertknight@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -52,7 +39,7 @@ void ScreenWindow::setScreen(Screen *screen)
         return;
     }
 
-    emit screenAboutToChange();
+    Q_EMIT screenAboutToChange();
     _screen = screen;
 }
 
@@ -152,7 +139,7 @@ void ScreenWindow::setSelectionStart(int column, int line, bool columnMode)
     _screen->setSelectionStart(column, line + currentLine(), columnMode);
 
     _bufferNeedsUpdate = true;
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
 void ScreenWindow::setSelectionEnd(int column, int line)
@@ -160,7 +147,7 @@ void ScreenWindow::setSelectionEnd(int column, int line)
     _screen->setSelectionEnd(column, line + currentLine());
 
     _bufferNeedsUpdate = true;
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
 void ScreenWindow::setSelectionByLineRange(int start, int end)
@@ -171,7 +158,7 @@ void ScreenWindow::setSelectionByLineRange(int start, int end)
     _screen->setSelectionEnd(windowColumns(), end);
 
     _bufferNeedsUpdate = true;
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
 bool ScreenWindow::isSelected(int column, int line)
@@ -183,7 +170,7 @@ void ScreenWindow::clearSelection()
 {
     _screen->clearSelection();
 
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
 void ScreenWindow::setWindowLines(int lines)
@@ -239,7 +226,7 @@ void ScreenWindow::setCurrentResultLine(int line)
     }
 
     _currentResultLine = line;
-    emit currentResultLineChanged();
+    Q_EMIT currentResultLineChanged();
 }
 
 void ScreenWindow::scrollBy(RelativeScrollMode mode, int amount, bool fullPage)
@@ -274,7 +261,7 @@ void ScreenWindow::scrollTo(int line)
 
     _bufferNeedsUpdate = true;
 
-    emit scrolled(_currentLine);
+    Q_EMIT scrolled(_currentLine);
 }
 
 void ScreenWindow::setTrackOutput(bool trackOutput)
@@ -303,10 +290,21 @@ QRect ScreenWindow::scrollRegion() const
 
     if (atEndOfOutput() && equalToScreenSize) {
         return _screen->lastScrolledRegion();
-    } 
+    }
     return {0, 0, windowColumns(), windowLines()};
 }
 
+void ScreenWindow::updateCurrentLine()
+{
+    if (!_screen->isResize()) {
+        return;
+    }
+    if (_currentLine > 0) {
+        _currentLine -= _screen->getOldTotalLines() - lineCount();
+    }
+    _currentLine = qBound(0, _currentLine, lineCount() - windowLines());
+}
+
 void ScreenWindow::notifyOutputChanged()
 {
     // move window to the bottom of the screen and update scroll count
@@ -330,5 +328,5 @@ void ScreenWindow::notifyOutputChanged()
 
     _bufferNeedsUpdate = true;
 
-    emit outputChanged();
+    Q_EMIT outputChanged();
 }
