@@ -1,21 +1,7 @@
 /*
-    This file is part of Konsole, an X terminal.
-    Copyright 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
+    SPDX-FileCopyrightText: 1997, 1998 Lars Doelle <lars.doelle@on-line.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef HISTORYSCROLLNONE_H
@@ -40,12 +26,22 @@ public:
     bool hasScroll() override;
 
     int  getLines() override;
+    int  getMaxLines() override;
     int  getLineLen(int lineno) override;
     void getCells(int lineno, int colno, int count, Character res[]) override;
     bool isWrappedLine(int lineno) override;
 
     void addCells(const Character a[], int count) override;
     void addLine(bool previousWrapped = false) override;
+
+    // Modify history (do nothing here)
+    void insertCellsVector(int position, const QVector<Character> &cells) override;
+    void insertCells(int position, const Character a[], int count) override;
+    void removeCells(int position) override;
+    void setCellsAt(int position, const Character a[], int count) override;
+    void setCellsVectorAt(int position, const QVector<Character> &cells) override;
+    void setLineAt(int position, bool previousWrapped) override;
+    int reflowLines(int) override;
 };
 
 }
