@@ -1,20 +1,7 @@
 /*
-    Copyright 2006-2008 by Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Robert Knight <robertknight@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // To time the creation and total launch time (i. e. until window is
@@ -110,26 +97,9 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
         needToDeleteQApplication = true;
     }
 
-#if defined(Q_OS_LINUX) && (QT_VERSION < QT_VERSION_CHECK(5, 11, 2))
-    // Workaround for https://bugreports.qt.io/browse/QTBUG-48344
-    // See also https://bugs.kde.org/show_bug.cgi?id=230184
-    // The Qt glib event loop doesn't let timers deliver events if there are a
-    // lot of other events.
-    const QByteArray qtUseGLibOld = qgetenv("QT_NO_GLIB");
-    qputenv("QT_NO_GLIB", "1");
-#endif
-
     auto app = new QApplication(argc, argv);
     app->setStyle(new MenuStyle());
 
-#if defined(Q_OS_LINUX) && (QT_VERSION < QT_VERSION_CHECK(5, 11, 2))
-    if (qtUseGLibOld.isNull()) {
-        qunsetenv("QT_NO_GLIB");
-    } else {
-        qputenv("QT_NO_GLIB", qtUseGLibOld);
-    }
-#endif
-
 #if defined(Q_OS_MACOS)
     // this ensures that Ctrl and Meta are not swapped, so CTRL-C and friends
     // will work correctly in the terminal
@@ -190,9 +160,8 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char *argv[])
     needToDeleteQApplication = false;
 
     Kdelibs4ConfigMigrator migrate(QStringLiteral("konsole"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("konsolerc")
-                                         << QStringLiteral("konsole.notifyrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("sessionui.rc") << QStringLiteral("partui.rc") << QStringLiteral("konsoleui.rc"));
+    migrate.setConfigFiles({QStringLiteral("konsolerc"), QStringLiteral("konsole.notifyrc")});
+    migrate.setUiFiles({QStringLiteral("sessionui.rc"), QStringLiteral("partui.rc"), QStringLiteral("konsoleui.rc")});
 
     if (migrate.migrate()) {
         Kdelibs4Migration dataMigrator;
