@@ -1,21 +1,8 @@
 /*
-    Copyright 2006-2008 by Robert Knight <robertknight@gmail.com>
-    Copyright 2009 by Thomas Dreibholz <dreibh@iem.uni-due.de>
+    SPDX-FileCopyrightText: 2006-2008 Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2009 Thomas Dreibholz <dreibh@iem.uni-due.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SESSIONCONTROLLER_H
@@ -61,6 +48,7 @@ class Session;
 class SessionGroup;
 class TerminalDisplay;
 class UrlFilter;
+class ColorFilter;
 
 /**
  * Provides the menu actions to manipulate a single terminal session and view pair.
@@ -98,13 +86,13 @@ public:
     ~SessionController() override;
 
     /** Returns the session associated with this controller */
-    QPointer<Session> session()
+    QPointer<Session> session() const
     {
         return _sessionDisplayConnection->session();
     }
 
     /** Returns the view associated with this controller */
-    QPointer<TerminalDisplay> view()
+    QPointer<TerminalDisplay> view() const
     {
         return _sessionDisplayConnection->view();
     }
@@ -275,7 +263,7 @@ private Q_SLOTS:
     void searchTextChanged(const QString &text);
     void searchCompleted(bool success);
 
-    void updateFilterList(QExplicitlySharedDataPointer<Profile> profile); // Called when the profile has changed, so we might need to change the list of filters
+    void updateFilterList(const QExplicitlySharedDataPointer<Profile> &profile); // Called when the profile has changed, so we might need to change the list of filters
 
     void viewFocusChangeHandler(bool focused);
     void interactionHandler();
@@ -331,6 +319,7 @@ private:
     RegExpFilter *_searchFilter;
     UrlFilter *_urlFilter;
     FileFilter *_fileFilter;
+    ColorFilter *_colorFilter;
 
     QAction *_copyInputToAllTabsAction;
 
