@@ -90,13 +90,20 @@ void ProfileSettings::populateTable()
     connect(profilesList->selectionModel(), &QItemSelectionModel::selectionChanged, this, &Konsole::ProfileSettings::tableSelectionChanged);
 }
 
-void ProfileSettings::tableSelectionChanged(const QItemSelection&)
+void ProfileSettings::tableSelectionChanged(const QItemSelection &selected)
 {
+    newProfileButton->setEnabled(true);
+
+    if (selected.isEmpty()) {
+        editProfileButton->setEnabled(false);
+        deleteProfileButton->setEnabled(false);
+        setAsDefaultButton->setEnabled(false);
+        return;
+    }
+
     const auto profile = currentProfile();
     const bool isNotDefault = profile != ProfileManager::instance()->defaultProfile();
 
-    newProfileButton->setEnabled(true);
-
     // See comment about isProfileWritable(profile) in editSelected()
     editProfileButton->setEnabled(isProfileWritable(profile));
 
@@ -126,18 +133,17 @@ void ProfileSettings::setSelectedAsDefault()
 
 void ProfileSettings::createProfile()
 {
-    // setup a temporary profile which is a clone of the selected profile
-    // or the default if no profile is selected
-    Profile::Ptr sourceProfile = currentProfile() ? currentProfile() : ProfileManager::instance()->defaultProfile();
-
-    Q_ASSERT(sourceProfile);
-
     auto newProfile = Profile::Ptr(new Profile(ProfileManager::instance()->fallbackProfile()));
-    newProfile->clone(sourceProfile, true);
-    // TODO: add number suffix when the name is taken
-    newProfile->setProperty(Profile::Name, i18nc("@item This will be used as part of the file name", "New Profile"));
-    newProfile->setProperty(Profile::UntranslatedName, QStringLiteral("New Profile"));
-    newProfile->setProperty(Profile::MenuIndex, QStringLiteral("0"));
+
+    // If a profile is selected, clone its properties, otherwise the
+    // the fallback profile properties will be used
+    if (currentProfile()) {
+        newProfile->clone(currentProfile(), true);
+    }
+
+    const QString uniqueName = ProfileManager::instance()->generateUniqueName();
+    newProfile->setProperty(Profile::Name, uniqueName);
+    newProfile->setProperty(Profile::UntranslatedName, uniqueName);
 
     // Consider https://blogs.kde.org/2009/03/26/how-crash-almost-every-qtkde-application-and-how-fix-it-0 before changing the below
     QPointer<EditProfileDialog> dialog = new EditProfileDialog(this);
@@ -190,7 +196,7 @@ Profile::Ptr ProfileSettings::currentProfile() const
 {
     QItemSelectionModel* selection = profilesList->selectionModel();
 
-    if ((selection == nullptr) || selection->selectedRows().count() != 1) {
+    if ((selection == nullptr) || !selection->hasSelection()) {
         return Profile::Ptr();
     }
 
